==> lightdash_client_python-0.1286.0.tar.gz: lightdash_client_python-0.1286.0/lightdash_client/models/knex_paginated_data_organization_member_profile_array.py <==
from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.knex_paginated_data_organization_member_profile_array_pagination import (
        KnexPaginatedDataOrganizationMemberProfileArrayPagination,
    )
    from ..models.organization_member_profile import OrganizationMemberProfile


T = TypeVar("T", bound="KnexPaginatedDataOrganizationMemberProfileArray")


@_attrs_define
class KnexPaginatedDataOrganizationMemberProfileArray:
    """
    Attributes:
        data (List['OrganizationMemberProfile']):
        pagination (Union[Unset, KnexPaginatedDataOrganizationMemberProfileArrayPagination]):
    """

    data: List["OrganizationMemberProfile"]
    pagination: Union[Unset, "KnexPaginatedDataOrganizationMemberProfileArrayPagination"] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        data = []
        for data_item_data in self.data:
            data_item = data_item_data.to_dict()
            data.append(data_item)

        pagination: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.pagination, Unset):
            pagination = self.pagination.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "data": data,
            }
        )
        if pagination is not UNSET:
            field_dict["pagination"] = pagination

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.knex_paginated_data_organization_member_profile_array_pagination import (
            KnexPaginatedDataOrganizationMemberProfileArrayPagination,
        )
        from ..models.organization_member_profile import OrganizationMemberProfile

        d = src_dict.copy()
        data = []
        _data = d.pop("data")
        for data_item_data in _data:
            data_item = OrganizationMemberProfile.from_dict(data_item_data)

            data.append(data_item)

        _pagination = d.pop("pagination", UNSET)
        pagination: Union[Unset, KnexPaginatedDataOrganizationMemberProfileArrayPagination]
        if isinstance(_pagination, Unset):
            pagination = UNSET
        else:
            pagination = KnexPaginatedDataOrganizationMemberProfileArrayPagination.from_dict(_pagination)

        knex_paginated_data_organization_member_profile_array = cls(
            data=data,
            pagination=pagination,
        )

        knex_paginated_data_organization_member_profile_array.additional_properties = d
        return knex_paginated_data_organization_member_profile_array

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties

==> lightdash_client_python-0.1398.0.tar.gz: lightdash_client_python-0.1398.0/lightdash_client/models/knex_paginated_data_organization_member_profile_array.py <==
from typing import TYPE_CHECKING, Any, BinaryIO, Dict, List, Optional, TextIO, Tuple, Type, TypeVar, Union, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.knex_paginated_data_organization_member_profile_array_pagination import (
        KnexPaginatedDataOrganizationMemberProfileArrayPagination,
    )
    from ..models.organization_member_profile import OrganizationMemberProfile


T = TypeVar("T", bound="KnexPaginatedDataOrganizationMemberProfileArray")


@_attrs_define
class KnexPaginatedDataOrganizationMemberProfileArray:
    """
    Attributes:
        data (List['OrganizationMemberProfile']):
        pagination (Union[Unset, KnexPaginatedDataOrganizationMemberProfileArrayPagination]):
    """

    data: List["OrganizationMemberProfile"]
    pagination: Union[Unset, "KnexPaginatedDataOrganizationMemberProfileArrayPagination"] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        from ..models.knex_paginated_data_organization_member_profile_array_pagination import (
            KnexPaginatedDataOrganizationMemberProfileArrayPagination,
        )
        from ..models.organization_member_profile import OrganizationMemberProfile

        data = []
        for data_item_data in self.data:
            data_item = data_item_data.to_dict()
            data.append(data_item)

        pagination: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.pagination, Unset):
            pagination = self.pagination.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "data": data,
            }
        )
        if pagination is not UNSET:
            field_dict["pagination"] = pagination

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.knex_paginated_data_organization_member_profile_array_pagination import (
            KnexPaginatedDataOrganizationMemberProfileArrayPagination,
        )
        from ..models.organization_member_profile import OrganizationMemberProfile

        d = src_dict.copy()
        data = []
        _data = d.pop("data")
        for data_item_data in _data:
            data_item = OrganizationMemberProfile.from_dict(data_item_data)

            data.append(data_item)

        _pagination = d.pop("pagination", UNSET)
        pagination: Union[Unset, KnexPaginatedDataOrganizationMemberProfileArrayPagination]
        if isinstance(_pagination, Unset):
            pagination = UNSET
        else:
            pagination = KnexPaginatedDataOrganizationMemberProfileArrayPagination.from_dict(_pagination)

        knex_paginated_data_organization_member_profile_array = cls(
            data=data,
            pagination=pagination,
        )

        knex_paginated_data_organization_member_profile_array.additional_properties = d
        return knex_paginated_data_organization_member_profile_array

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
